==> haskell-dav-1.3.1-71-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DAV
version: 1.3.1
id: DAV-1.3.1-DAkEG0uEBbU866Z4SbCPQx
key: DAV-1.3.1-DAkEG0uEBbU866Z4SbCPQx
license: GPL-3
copyright: Copyright (C) 2012-2016  Clint Adams
maintainer: clint@debian.org
homepage: http://floss.scru.org/hDAV
synopsis: RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.
    .
    In addition, there is an executable, hdav, which can be used for
    command-line operation.
category: Web
author: Clint Adams
exposed: True
exposed-modules:
    Network.Protocol.HTTP.DAV
hidden-modules: Network.Protocol.HTTP.DAV.TH
abi: b72699adc79def24ce768c4dfef09809
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/DAV-1.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/DAV-1.3.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/DAV-1.3.1
hs-libraries: HSDAV-1.3.1-DAkEG0uEBbU866Z4SbCPQx
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi containers-0.5.7.1
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    http-client-0.5.6.1-LjnNcxn7EAdDT87PUFggs5
    http-client-tls-0.3.4-Jtdy68AY0Ab6sKc1XAFld3
    http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
    lens-4.15.1-AQi0y6GexOY2BzSazyYQSD mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    transformers-0.5.2.0 transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
    xml-conduit-1.4.0.4-6KlI1EEuaBxFl9o9QI4uWc
    xml-hamlet-0.4.1-LEXgm4BmhDF7mKR7PJpj0b
haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html: /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dav-1.3.1-85-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DAV
version: 1.3.1
id: DAV-1.3.1-L6YntIqsnFG9OpRGhuk1wz
key: DAV-1.3.1-L6YntIqsnFG9OpRGhuk1wz
license: GPL-3
copyright: Copyright (C) 2012-2016  Clint Adams
maintainer: clint@debian.org
homepage: http://floss.scru.org/hDAV
synopsis: RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.
    .
    In addition, there is an executable, hdav, which can be used for
    command-line operation.
category: Web
author: Clint Adams
exposed: True
exposed-modules:
    Network.Protocol.HTTP.DAV
hidden-modules: Network.Protocol.HTTP.DAV.TH
abi: 564dd8dcc626b5782a787e4cfd5da225
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/DAV-1.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/DAV-1.3.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/DAV-1.3.1
hs-libraries: HSDAV-1.3.1-L6YntIqsnFG9OpRGhuk1wz
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.9-HR7ngNnTOX66jDpe7AgOeu containers-0.5.7.1
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    http-client-0.5.6.1-wVCkiPnh0GHIyvDsvtfzo
    http-client-tls-0.3.4.1-F1daH9Hnpr59fYvwc6jAf5
    http-types-0.9.1-E37jBtYKNpTKS6SyGsLwFU
    lens-4.15.1-85We4dJu1XfCMsVbDUwkFu mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    transformers-0.5.2.0 transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
    xml-conduit-1.4.0.4-4JMNsrmqa8CJ6lSm2Ik1gQ
    xml-hamlet-0.4.1-LnjS8BRIxHLLALhudWcTON
haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html: /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
